@@ -12,12 +12,12 @@ from xml.dom.minidom import parseString
 from time import sleep
 
 from pynessus.models.scan import Scan
-from models.tag import Tag
-from models.policy import Policy
-from models.user import User
-from models.report import Report
-from models.plugin import PluginFamily, Plugin
-from models.preference import PreferenceValue, Preference
+from pynessus.models.tag import Tag
+from pynessus.models.policy import Policy
+from pynessus.models.user import User
+from pynessus.models.report import Report
+from pynessus.models.plugin import PluginFamily, Plugin
+from pynessus.models.preference import PreferenceValue, Preference
 
 
 class NessusAPIError(Exception):
